# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/compare/v0.1.0...0340db71b9d54dc0238fa79f17dfe50e98078d58))

### Enhancements made

- Bump to support JupyterLab 4.0 [#11](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/11) ([@yuvipanda](https://github.com/yuvipanda))

### Maintenance and upkeep improvements

- Bump postcss from 8.4.25 to 8.4.31 [#10](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/10) ([@dependabot](https://github.com/dependabot))
- Bump word-wrap from 1.2.3 to 1.2.4 [#8](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/8) ([@dependabot](https://github.com/dependabot))
- Bump semver from 5.7.1 to 5.7.2 [#7](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/7) ([@dependabot](https://github.com/dependabot))
- Bump stylelint from 14.16.1 to 15.10.1 [#6](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/6) ([@dependabot](https://github.com/dependabot))
- Fix prettier config [#4](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/4) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add extension status badge [#5](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/5) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/graphs/contributors?from=2023-04-06&to=2024-01-15&type=c))

[@dependabot](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-open-url-parameter+involves%3Adependabot+updated%3A2023-04-06..2024-01-15&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-open-url-parameter+involves%3Agithub-actions+updated%3A2023-04-06..2024-01-15&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-open-url-parameter+involves%3Ajtpio+updated%3A2023-04-06..2024-01-15&type=Issues) | [@yuvipanda](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-open-url-parameter+involves%3Ayuvipanda+updated%3A2023-04-06..2024-01-15&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/compare/49b6de109486817ee3abaf253cd2c6f0f04c54cc...cb8aa69ee7e20f413fa93a85c848d03e8640a0a9))

### Maintenance and upkeep improvements

- Reset version to 0.0.1 in preparation for release [#3](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/3) ([@jtpio](https://github.com/jtpio))
- Fix CI [#1](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/1) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add files for JupyterLite [#2](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/pull/2) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-open-url-parameter/graphs/contributors?from=2023-04-06&to=2023-04-06&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-open-url-parameter+involves%3Agithub-actions+updated%3A2023-04-06..2023-04-06&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-open-url-parameter+involves%3Ajtpio+updated%3A2023-04-06..2023-04-06&type=Issues)
